Documentation for pymnl — pymnl 0.6 documentation

# pymnl 0.6 documentation

## Documentation for pymnl

pymnl (rhymes with hymnal) is a pure Python re-implmentation of libmnl and provides a minimal interface to Linux Netlink sockets and messages. The author and maintainer is Sean Robinson <robinson@tuxfamily.org>.

pymnl should be compatible with Python > 2.4. An effort has been made to allow pymnl to work with Py2 and Py3 from a single code base. See "Using pymnl with Python 2 vs Python 3" for version-specific caveats.

More information is available at http://pymnl.tuxfamily.org.

See the API checklist for a detailed list of which libmnl functions have been implemented.

A short changelog describes the general and API changes for every release.

## Example Applications

The examples directory contains small examples of how to use pymnl with various Netlink protocols. These are re-implementations of the examples provided in libmnl.

## License

pymnl is licensed under LGPLv2+, however, the examples are licensed under GPLv2+.

## Modules

> - pymnl
> - pymnl.attributes
> - pymnl.genl
> - pymnl.message
> - pymnl.nlsocket

## Warranty

There is none. Do not rely on it for anything. It could cause your computer to apply for a second mortgage on your home, take your underage children to R-rated movies, or run around your neighborhood in the middle of the night ringing doorbells. You. Have. Been. Warned.

# Indices and tables

- Index
- Module Index
- Search Page